OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Tambah ke favorit",
    "Removed from favorites" : "Terbuang dari favorit",
    "You added {file} to your favorites" : "Anda menambahkan {file} ke favorit",
    "You removed {file} from your favorites" : "Anda membuang {file} dari favorit",
    "Favorites" : "Favorit",
    "File changes" : "Berkas berubah",
    "Created by {user}" : "Dibuat oleh {user}",
    "Changed by {user}" : "Diubah oleh {user}",
    "Deleted by {user}" : "Dihapus oleh {user}",
    "Restored by {user}" : "Dipulihkan oleh {user}",
    "Renamed by {user}" : "Diganti nama oleh {user}",
    "Moved by {user}" : "Dipindahkan oleh {user}",
    "\"remote account\"" : "\"akun jarak jauh\"",
    "You created {file}" : "Anda membuat {file}",
    "You created an encrypted file in {file}" : "Anda membuat berkas terenkripsi pada {file}",
    "{user} created {file}" : "{user} membuat {file}",
    "{user} created an encrypted file in {file}" : "{user} membuat berkas terenkripsi pada {file}",
    "{file} was created in a public folder" : "{file} dibuat pada folder publik",
    "You changed {file}" : "Anda mengubah {file}",
    "You changed an encrypted file in {file}" : "Anda mengubah berkas terenkripsi pada {file}",
    "{user} changed {file}" : "{user} mengubah {file}",
    "{user} changed an encrypted file in {file}" : "{user} mengubah berkas terenkripsi pada {file}",
    "You deleted {file}" : "Anda menghapus {file}",
    "You deleted an encrypted file in {file}" : "Anda menghapus berkas terenkripsi pada {file}",
    "{user} deleted {file}" : "{user} menghapus {file}",
    "{user} deleted an encrypted file in {file}" : "{user} menghapus berkas terenkripsi pada {file}",
    "You restored {file}" : "Anda memulihkan {file}",
    "{user} restored {file}" : "{user} memulihkan {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Anda mengubah nama {oldfile} (tersembunyi) ke {newfile} (tersembunyi)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Anda mengubah nama {oldfile} (tersembunyi) ke {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Anda mengubah nama {oldfile} ke {newfile} (tersembunyi)",
    "You renamed {oldfile} to {newfile}" : "Anda mengganti nama {oldfile} menjadi {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} mengubah nama {oldfile} (tersembunyi) ke {newfile} (tersembunyi)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} mengubah nama {oldfile} (tersembunyi) ke {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} mengubah nama {oldfile} ke {newfile} (tersebunyi)",
    "{user} renamed {oldfile} to {newfile}" : "{user} mengganti nama {oldfile} menjadi {newfile}",
    "You moved {oldfile} to {newfile}" : "Anda memindahkan {oldfile} menjadi {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} memindahkan {oldfile} menjadi {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Suatu berkas telah ditambahkan atau dibuang dari <strong>favorit</strong>",
    "Files" : "Berkas",
    "A file or folder has been <strong>changed</strong>" : "Sebuah berkas atau folder telah <strong>diubah</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Sebuah berkas atau folder favorit telah <strong>diubah</strong>",
    "Failed to authorize" : "Gagal mengautorisasi",
    "Invalid folder path" : "Jalur folder tidak valid",
    "Folder not found" : "Folder tidak ditemukan",
    "The file cannot be found" : "File tidak dapat ditemukan",
    "The destination path does not exist: %1$s" : "Jalur tujuan tidak ada: %1$s",
    "You do not have permission to create a file at the specified location" : "Anda tidak memiliki izin untuk membuat file di lokasi yang ditentukan",
    "The file could not be converted." : "File tidak dapat dikonversi.",
    "Could not get relative path to converted file" : "Tidak dapat memperoleh jalur relatif ke file yang dikonversi",
    "Limit must be a positive integer." : "Batas harus berupa bilangan bulat positif.",
    "The replacement character may only be a single character." : "Karakter pengganti hanya boleh satu karakter.",
    "Filename sanitization already started." : "Sanitasi nama file sudah dimulai.",
    "No filename sanitization in progress." : "Tidak ada sanitasi nama file yang sedang berlangsung.",
    "Favorite files" : "File favorit",
    "No favorites" : "Tidak ada favorit",
    "More favorites" : "Favorit lainnya",
    "Accept" : "Terima",
    "Reject" : "Ditolak",
    "Incoming ownership transfer from {user}" : "Permintaan transfer kepemilikan dari {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Apakah Anda ingin menerima {path}?\n\nCatatan: Setelah diterima, proses transfer butuh kurang lebih 1 jam.",
    "Ownership transfer denied" : "Transfer kepemilikan ditolak",
    "Your ownership transfer of {path} was denied by {user}." : "Transfer kepemilikan Anda atas {path} ditolak oleh {user}.",
    "Ownership transfer failed" : "Transfer kepemilikan gagal",
    "Your ownership transfer of {path} to {user} failed." : "Transfer kepemilikan Anda pada {path} ke {user} gagal.",
    "The ownership transfer of {path} from {user} failed." : "Transfer kepemilikan pada {path} dari {user} gagal.",
    "Ownership transfer done" : "Transfer kepemilikan selesai",
    "Your ownership transfer of {path} to {user} has completed." : "Transfer kepemilikan Anda pada {path} ke {user} selesai.",
    "The ownership transfer of {path} from {user} has completed." : "Transfer kepemilikan pada {path} dari {user} selesai.",
    "in %s" : "dalam %s",
    "Transferred from %1$s on %2$s" : "Ditransfer dari %1$s pada %2$s",
    "File Management" : "Pengelolaan Berkas",
    "Home" : "Beranda",
    "Target folder does not exist any more" : "Folder target sudah tidak ada lagi",
    "Reload current directory" : "Muat ulang direktori saat ini",
    "Go to the \"{dir}\" directory" : "Buka direktori \"{dir}\"",
    "Current directory path" : "Jalur direktori saat ini",
    "Share" : "Bagikan",
    "Your have used your space quota and cannot upload files anymore" : "Anda telah menggunakan kuota ruang Anda dan tidak dapat mengunggah file lagi",
    "You do not have permission to upload or create files here." : "Anda tidak memiliki izin untuk mengunggah atau membuat file di sini.",
    "Drag and drop files here to upload" : "Seret dan lepaskan file di sini untuk mengunggah",
    "Favorite" : "Favorit",
    "Back" : "Kembali",
    "Toggle selection for file \"{displayName}\"" : "Alihkan pilihan untuk file \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Alihkan pilihan untuk folder \"{displayName}\"",
    "File is loading" : "File sedang dimuat",
    "Folder is loading" : "Folder sedang dimuat",
    "Filename" : "Nama berkas",
    "Folder name" : "Nama folder",
    "This node is unavailable" : "Node ini tidak tersedia",
    "Another entry with the same name already exists." : "Entri lain dengan nama yang sama sudah ada.",
    "Invalid filename." : "Nama file tidak valid.",
    "Rename file" : "Ganti nama file",
    "Folder" : "Folder",
    "Unknown file type" : "Jenis file tidak dikenal",
    "{ext} image" : "Gambar {ext}",
    "{ext} video" : "Video {ext}",
    "{ext} audio" : "Audio {ext}",
    "{ext} text" : "Teks {ext}",
    "Pending" : "Tertunda",
    "Unknown date" : "Tanggal tidak diketahui",
    "Active filters" : "Filter aktif",
    "Remove filter" : "Hapus filter",
    "Today" : "Hari ini",
    "Last 7 days" : "7 hari terakhir",
    "Last 30 days" : "30 hari terakhir",
    "This year ({year})" : "Tahun ini ({year})",
    "Last year ({year})" : "Tahun lalu ({year})",
    "Custom date range" : "Rentang tanggal kustom",
    "Search everywhere" : "Cari di mana saja",
    "Documents" : "Dokumen",
    "Spreadsheets" : "Spreadsheet",
    "Presentations" : "Presentasi",
    "PDFs" : "PDF",
    "Folders" : "Folder",
    "Audio" : "Audio",
    "Images" : "Gambar",
    "Videos" : "Video",
    "Filters" : "Filter",
    "Appearance" : "Tampilan",
    "Show hidden files" : "Lihat berkas tersembunyi",
    "Show file type column" : "Tampilkan kolom jenis file",
    "Show file extensions" : "Tampilkan ekstensi file",
    "Crop image previews" : "Pangkas pratinjau gambar",
    "General" : "Umum",
    "Sort favorites first" : "Urutkan favorit terlebih dahulu",
    "Sort folders before files" : "Urutkan folder sebelum file",
    "Enable folder tree view" : "Aktifkan tampilan pohon folder",
    "Default view" : "Tampilan default",
    "All files" : "Semua berkas",
    "Personal files" : "Berkas pribadi",
    "Additional settings" : "Setelan tambahan",
    "Actions" : "Tindakan",
    "File actions" : "Tindakan file",
    "Selection" : "Pilihan",
    "Select all files" : "Pilih semua file",
    "Deselect all" : "Tidak ada yang dipilih",
    "Select or deselect" : "Pilih atau batal pilih",
    "Select a range" : "Pilih rentang",
    "Navigation" : "Navigasi",
    "Go to parent folder" : "Pergi ke folder induk",
    "Go to file above" : "Pergi ke file di atas",
    "Go to file below" : "Pergi ke file di bawah",
    "Go left in grid" : "Pergi ke kiri dalam grid",
    "Go right in grid" : "Pergi ke kanan dalam grid",
    "View" : "Tampilan",
    "Toggle grid view" : "Alihkan tampilan jala-jala",
    "Show those shortcuts" : "Tampilkan pintasan tersebut",
    "Warnings" : "Peringatan",
    "Warn before changing a file extension" : "Peringatkan sebelum mengubah ekstensi file",
    "Warn before deleting a file" : "Peringatkan sebelum menghapus file",
    "WebDAV URL" : "URL WebDAV",
    "Create an app password" : "Buat kata sandi aplikasi",
    "Required for WebDAV authentication because Two-Factor Authentication is enabled for this account." : "Diperlukan untuk autentikasi WebDAV karena Autentikasi Dua Faktor diaktifkan untuk akun ini.",
    "How to access files using WebDAV" : "Cara mengakses file menggunakan WebDAV",
    "Total rows summary" : "Ringkasan total baris",
    "Toggle selection for all files and folders" : "Alihkan pilihan untuk semua file dan folder",
    "Name" : "Nama",
    "File type" : "Jenis file",
    "Size" : "Ukuran",
    "Modified" : "Dimodifikasi",
    "{displayName}: failed on some elements" : "{displayName}: gagal pada beberapa elemen",
    "{displayName}: done" : "{displayName}: selesai",
    "{displayName}: failed" : "{displayName}: gagal",
    "(selected)" : "(dipilih)",
    "List of files and folders." : "Daftar file dan folder.",
    "You have used your space quota and cannot upload files anymore." : "Anda telah menggunakan kuota ruang Anda dan tidak dapat mengunggah file lagi.",
    "Column headers with buttons are sortable." : "Header kolom dengan tombol dapat diurutkan.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Daftar ini tidak dirender sepenuhnya demi alasan performa. File akan dirender saat Anda menavigasi melalui daftar.",
    "File not found" : "Berkas tidak ditemukan",
    "_{count} selected_::_{count} selected_" : ["{count} dipilih"],
    "Search everywhere …" : "Cari di mana saja …",
    "Search here …" : "Cari di sini …",
    "Search scope options" : "Opsi cakupan pencarian",
    "Search here" : "Cari di sini",
    "Owner" : "Pemilik",
    "{usedQuotaByte} used" : "{usedQuotaByte} digunakan",
    "{used} of {quota} used" : "{used} dari {quota} terpakai",
    "{relative}% used" : "{relative}% digunakan",
    "Could not refresh storage stats" : "Tidak dapat memuat ulang statistik penyimpanan",
    "Your storage is full, files can not be updated or synced anymore!" : "Ruang penyimpanan Anda penuh, berkas tidak dapat diperbarui atau disinkronkan lagi!",
    "Storage information" : "Informasi penyimpanan",
    "Storage quota" : "Kuota penyimpanan",
    "New folder" : "Folder baru",
    "Create new folder" : "Buat direktori baru",
    "This name is already in use." : "Nama ini sudah digunakan.",
    "Create" : "Buat",
    "Files starting with a dot are hidden by default" : "File yang diawali titik disembunyikan secara default",
    "Failed to start filename sanitization." : "Gagal memulai sanitasi nama file.",
    "Failed to refresh filename sanitization status." : "Gagal menyegarkan status sanitasi nama file.",
    "Filename sanitization in progress." : "Sanitasi nama file sedang berlangsung.",
    "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Saat ini {processedUsers} dari {totalUsers} akun sudah diproses.",
    "Preparing …" : "Menyiapkan …",
    "Refresh" : "Muat ulang",
    "All files have been santized for Windows filename support." : "Semua file telah disanitasi untuk dukungan nama file Windows.",
    "Some files could not be sanitized, please check your logs." : "Beberapa file tidak dapat disanitasi, silakan periksa log Anda.",
    "Sanitization errors" : "Kesalahan sanitasi",
    "Not sanitized filenames" : "Nama file yang tidak disanitasi",
    "Windows filename support has been enabled." : "Dukungan nama file Windows telah diaktifkan.",
    "While this blocks users from creating new files with unsupported filenames, existing files are not yet renamed and thus still may break sync on Windows." : "Meskipun ini mencegah pengguna membuat file baru dengan nama file yang tidak didukung, file yang sudah ada belum diganti nama dan karenanya masih dapat merusak sinkronisasi di Windows.",
    "You can trigger a rename of files with invalid filenames, this will be done in the background and may take some time." : "Anda dapat memicu penggantian nama file dengan nama file tidak valid, ini akan dilakukan di latar belakang dan mungkin memerlukan waktu.",
    "Please note that this may cause high workload on the sync clients." : "Harap dicatat bahwa ini dapat menyebabkan beban kerja tinggi pada klien sinkronisasi.",
    "Limit" : "Batas",
    "This allows to configure how many users should be processed in one background job run." : "Ini memungkinkan pengaturan berapa banyak pengguna yang harus diproses dalam satu kali menjalankan tugas latar belakang.",
    "Sanitize filenames" : "Sanitasi nama file",
    "(starting)" : "(memulai)",
    "Fill template fields" : "Isi kolom template",
    "Submitting fields …" : "Mengirim kolom …",
    "Submit" : "Kirim",
    "Choose a file or folder to transfer" : "Pilih berkas atau folder untuk ditransfer",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Transfer {path} ke {userid}",
    "Invalid path selected" : "Jalur terpilih invalid",
    "Unknown error" : "Kesalahan tidak diketahui",
    "Ownership transfer request sent" : "Permintaan transfer kepemilikan terkirim",
    "Cannot transfer ownership of a file or folder you do not own" : "Tidak dapat mentransfer pemilik berkas atau folder yang Anda tidak miliki",
    "Transfer ownership of a file or folder" : "Transfer kepemilikan dari berkas atau folder",
    "Choose file or folder to transfer" : "Pilih berkas atau folder untuk transfer",
    "Change" : "Ubah",
    "New owner" : "Pemilik baru",
    "Keep {old}" : "Pertahankan {old}",
    "Keep without extension" : "Pertahankan tanpa ekstensi",
    "Use {new}" : "Gunakan {new}",
    "Remove extension" : "Hapus ekstensi",
    "Change file extension" : "Ubah ekstensi file",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Mengubah ekstensi file dari \"{old}\" menjadi \"{new}\" dapat membuat file tidak dapat dibaca.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Menghapus ekstensi file \"{old}\" dapat membuat file tidak dapat dibaca.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Menambahkan ekstensi file \"{new}\" dapat membuat file tidak dapat dibaca.",
    "Do not show this dialog again." : "Jangan tampilkan dialog ini lagi.",
    "Cancel" : "Membatalkan",
    "Rename" : "Ubah nama",
    "Select file or folder to link to" : "Pilih berkas atau folder untuk ditautkan",
    "Choose {file}" : "Pilih {file}",
    "Files settings" : "Setelan berkas",
    "Switch to list view" : "Beralih ke tampilan daftar",
    "Switch to grid view" : "Beralih ke tampilan grid",
    "The file could not be found" : "File tidak dapat ditemukan",
    "Upload was cancelled by user" : "Unggahan dibatalkan oleh pengguna",
    "Not enough free space" : "Ruang kosong tidak cukup",
    "Operation is blocked by access control" : "Tindakan diblokir oleh kontrol akses",
    "Error during upload: {message}" : "Kesalahan saat mengunggah: {message}",
    "Error during upload, status code {status}" : "Kesalahan saat mengunggah, kode status {status}",
    "Unknown error during upload" : "Kesalahan tidak dikenal saat mengunggah",
    "Loading current folder" : "Memuat folder saat ini",
    "Retry" : "Ulangi",
    "No files in here" : "Tidak ada berkas di sini",
    "Upload some content or sync with your devices!" : "Unggah beberapa konten dan sinkronisasikan dengan perangkat Anda!",
    "Go back" : "Kembali",
    "Views" : "Tampilan",
    "Loading …" : "Memuat …",
    "Your files" : "File Anda",
    "Open in files" : "Buka di File",
    "File cannot be accessed" : "Berkas tidak dapat diakses",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "File tidak dapat ditemukan atau Anda tidak memiliki izin untuk melihatnya. Minta pengirim untuk membagikannya.",
    "No search results for “{query}”" : "Tidak ada hasil pencarian untuk “{query}”",
    "Search for files" : "Cari file",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Izinkan pembatasan nama file untuk memastikan file dapat disinkronkan dengan semua klien. Secara default, semua nama file yang valid pada POSIX (misalnya Linux atau macOS) diizinkan.",
    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Setelah mengaktifkan nama file yang kompatibel dengan Windows, file yang sudah ada tidak dapat dimodifikasi lagi, tetapi dapat diganti nama menjadi nama baru yang valid oleh pemiliknya.",
    "Failed to toggle Windows filename support" : "Gagal mengalihkan dukungan nama file Windows",
    "Files compatibility" : "Kompatibilitas file",
    "Enforce Windows compatibility" : "Terapkan kompatibilitas Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Ini akan memblokir nama file yang tidak valid pada sistem Windows, seperti penggunaan nama yang dicadangkan atau karakter khusus. Namun ini tidak akan menerapkan kompatibilitas terkait sensitivitas huruf besar/kecil.",
    "Blank" : "Kosong",
    "Unable to create new file from template" : "Tidak dapat membuat berkas baru dari templat",
    "Pick a template for {name}" : "Pilih templat untuk {name}",
    "Create a new file with the selected template" : "Buat sebuah berkas baru dengan templat yang dipilih",
    "Creating file" : "Membuat berkas",
    "Save as {displayName}" : "Simpan sebagai {displayName}",
    "Save as …" : "Simpan sebagai …",
    "Converting files …" : "Mengonversi file …",
    "Failed to convert files: {message}" : "Gagal mengonversi file: {message}",
    "All files failed to be converted" : "Semua file gagal dikonversi",
    "One file could not be converted: {message}" : "Satu file tidak dapat dikonversi: {message}",
    "_%n file could not be converted_::_%n files could not be converted_" : ["%n file tidak dapat dikonversi"],
    "_%n file converted_::_%n files converted_" : ["%n file dikonversi"],
    "Files converted" : "File dikonversi",
    "Failed to convert files" : "Gagal mengonversi file",
    "Converting file …" : "Mengonversi file …",
    "File successfully converted" : "File berhasil dikonversi",
    "Failed to convert file: {message}" : "Gagal mengonversi file: {message}",
    "Failed to convert file" : "Gagal mengonversi file",
    "Delete" : "Hapus",
    "Leave this share" : "Tinggalkan pembagian ini",
    "Leave these shares" : "Tinggalkan berbagi ini",
    "Disconnect storage" : "Memutuskan penyimpaan",
    "Disconnect storages" : "Putuskan penyimpanan",
    "Delete permanently" : "Hapus secara permanen",
    "Delete and unshare" : "Hapus dan batalkan berbagi",
    "Delete file" : "Hapus file",
    "Delete files" : "Hapus file",
    "Delete folder" : "Hapus folder",
    "Delete folders" : "Hapus folder",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Anda akan menghapus {count} item secara permanen"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Anda akan menghapus {count} item"],
    "Confirm deletion" : "Konfirmasi penghapusan",
    "Download" : "Unduh",
    "The requested file is not available." : "File yang diminta tidak tersedia.",
    "The requested files are not available." : "File yang diminta tidak tersedia.",
    "Add to favorites" : "Tambah ke favorit",
    "Remove from favorites" : "Remove from favorites",
    "Add or remove favorite" : "Tambahkan atau hapus favorit",
    "Move" : "Pindah",
    "Copy" : "Salin",
    "Move or copy" : "Pindah atau salin",
    "Destination is not a folder" : "Tujuan bukan folder",
    "This file/folder is already in that directory" : "File/folder ini sudah ada di direktori tersebut",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Anda tidak dapat memindahkan file/folder ke dirinya sendiri atau ke subfolder dari dirinya sendiri",
    "A file or folder with that name already exists in this folder" : "File atau folder dengan nama tersebut sudah ada di folder ini",
    "The files are locked" : "File terkunci",
    "The file does not exist anymore" : "File tersebut sudah tidak ada",
    "Moving \"{source}\" to \"{destination}\" …" : "Memindahkan \"{source}\" ke \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Menyalin \"{source}\" ke \"{destination}\" …",
    "Choose destination" : "Pilih tujuan",
    "Copy to {target}" : "Salin ke {target}",
    "Move to {target}" : "Pindahkan ke {target}",
    "Move or copy operation failed" : "Operasi pemindahan atau penyalinan gagal",
    "Open folder" : "Buka folder",
    "Open folder {displayName}" : "Buka folder {displayName}",
    "Open in Files" : "Buka di File",
    "Open locally" : "Buka secara lokal",
    "Failed to redirect to client" : "Gagal mengarahkan ke klien",
    "Open file locally" : "Buka file secara lokal",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "File seharusnya sekarang terbuka di perangkat Anda. Jika tidak, silakan periksa bahwa Anda telah menginstal aplikasi desktop.",
    "Retry and close" : "Coba lagi dan tutup",
    "Open online" : "Buka online",
    "Details" : "Rincian",
    "Open the details sidebar" : "Buka bilah sisi detail",
    "Unfavorite" : "Hapus dari favorit",
    "View in folder" : "Lihat dalam folder",
    "Type" : "tipe",
    "Created new folder \"{name}\"" : "Membuat folder baru \"{name}\"",
    "Unable to initialize the templates directory" : "Tidak dapat membuat direktori templat",
    "Create templates folder" : "Buat folder templat",
    "Templates" : "Templat",
    "New template folder" : "Folder templat baru",
    "In folder" : "Di folder",
    "Search in all files" : "Cari di semua file",
    "Search in folder: {folder}" : "Cari di folder: {folder}",
    "One of the dropped files could not be processed" : "Salah satu file yang dijatuhkan tidak dapat diproses",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Browser Anda tidak mendukung Filesystem API. Direktori tidak akan diunggah",
    "No files to upload" : "Tidak ada file untuk diunggah",
    "Unable to create the directory {directory}" : "Tidak dapat membuat direktori {directory}",
    "Some files could not be uploaded" : "Beberapa file tidak dapat diunggah",
    "Files uploaded successfully" : "File berhasil diunggah",
    "No files to process" : "Tidak ada file untuk diproses",
    "Files copied successfully" : "File berhasil disalin",
    "Files moved successfully" : "File berhasil dipindahkan",
    "Some files could not be copied" : "Beberapa file tidak dapat disalin",
    "Some files could not be moved" : "Beberapa berkas tidak dapat dipindahkan",
    "Conflicts resolution skipped" : "Penyelesaian konflik dilewati",
    "Upload cancelled" : "Unggahan dibatalkan",
    "Could not rename \"{oldName}\", it does not exist any more" : "Tidak dapat mengganti \"{oldName}\", tidak ada lagi",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nama \"{newName}\" sudah digunakan di folder \"{dir}\". Gunakan nama yang lain.",
    "Could not rename \"{oldName}\"" : "Tidak dapat mengganti \"{oldName}\"",
    "This operation is forbidden" : "Operasi ini dilarang",
    "This folder is unavailable, please try again later or contact the administration" : "Folder ini tidak tersedia, silakan coba lagi nanti atau hubungi administrasi",
    "Storage is temporarily not available" : "Penyimpanan sementara tidak tersedia",
    "Unexpected error: {error}" : "Kesalahan tak terduga: {error}",
    "_%n file_::_%n files_" : ["%n berkas"],
    "_%n folder_::_%n folders_" : ["%n folder"],
    "_%n hidden_::_%n hidden_" : ["%n disembunyikan"],
    "Filename must not be empty." : "Nama file tidak boleh kosong.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" tidak diperbolehkan di dalam nama file.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" adalah nama yang dicadangkan dan tidak diizinkan untuk nama file.",
    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" bukan jenis file yang diizinkan.",
    "Filenames must not end with \"{extension}\"." : "Nama file tidak boleh diakhiri dengan \"{extension}\".",
    "List of favorite files and folders." : "Daftar file dan folder favorit.",
    "No favorites yet" : "Belum memiliki favorit",
    "Files and folders you mark as favorite will show up here" : "Berkas dan folder yang Anda tandai sebagai favorit akan ditampilkan di sini.",
    "List of your files and folders." : "Daftar file dan folder Anda.",
    "Folder tree" : "Pohon folder",
    "List of your files and folders that are not shared." : "Daftar file dan folder Anda yang tidak dibagikan.",
    "No personal files found" : "Tidak ditemukan file pribadi",
    "Files that are not shared will show up here." : "File yang tidak dibagikan akan muncul di sini.",
    "Recent" : "Terbaru",
    "List of recently modified files and folders." : "Daftar file dan folder yang baru-baru ini Anda modifikasi.",
    "No recently modified files" : "Tidak ada file yang baru-baru ini dimodifikasi",
    "Files and folders you recently modified will show up here." : "File dan folder yang baru-baru ini Anda modifikasi akan muncul di sini.",
    "Search" : "Cari",
    "Search results within your files." : "Hasil pencarian di dalam file Anda.",
    "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
    "Select all" : "Pilih Semua",
    "Upload too large" : "Yang diunggah terlalu besar",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Berkas yang dicoba untuk diunggah melebihi ukuran maksimum pengunggahan berkas di server ini.",
    "%1$s (renamed)" : "%1$s (diganti nama)",
    "renamed file" : "file diganti nama",
    "Upload (max. %s)" : "Unggah (maks. %s)",
    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Setelah mengaktifkan nama file yang kompatibel dengan Windows, file yang sudah ada tidak dapat dimodifikasi lagi, tetapi dapat diganti nama menjadi nama baru yang valid oleh pemiliknya.",
    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "File juga dapat dimigrasikan secara otomatis setelah mengaktifkan pengaturan ini, silakan merujuk ke dokumentasi tentang perintah occ.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Mengganti nama \"{oldName}\" menjadi \"{newName}\"",
    "Clear filter" : "Bersihkan filter",
    "\"{displayName}\" failed on some elements" : "\"{displayName}\" gagal pada beberapa elemen",
    "\"{displayName}\" batch action executed successfully" : "Tindakan batch \"{displayName}\" berhasil dijalankan",
    "\"{displayName}\" action failed" : "Tindakan \"{displayName}\" gagal",
    "Submitting fields …" : "Mengirim kolom …",
    "Shared by link" : "Dibagikan dengan tautan",
    "Shared" : "Dibagikan",
    "\"{displayName}\" action executed successfully" : "Tindakan \"{displayName}\" berhasil dijalankan",
    "Filter file names …" : "Filter nama file …",
    "Clipboard is not available" : "Papan klip tidak tersedia",
    "WebDAV URL copied to clipboard" : "URL WebDAV disalin ke papan klip",
    "Enable the grid view" : "Aktifkan tampilan grid",
    "Enable folder tree" : "Aktifkan pohon folder",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Salin ke papan klip",
    "Use this address to access your Files via WebDAV" : "Gunakan alamat ini untuk mengakses Berkas Anda via WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Jika Anda telah mengaktifkan 2FA, Anda harus membuat dan menggunakan sebuah kata sandi aplikasi baru dengan mengeklik di sini.",
    "Prevent warning dialogs from open or reenable them." : "Cegah dialog peringatan agar tidak muncul atau aktifkan kembali dialog tersebut.",
    "Show a warning dialog when changing a file extension." : "Tampilkan dialog peringatan saat mengubah ekstensi file.",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Speed up your Files experience with these quick shortcuts." : "Percepat pengalaman File Anda dengan pintasan cepat ini.",
    "Open the actions menu for a file" : "Buka menu tindakan untuk sebuah file",
    "Rename a file" : "Ganti nama file",
    "Delete a file" : "Hapus file",
    "Favorite or remove a file from favorites" : "Jadikan favorit atau hapus file dari favorit",
    "Manage tags for a file" : "Kelola tag untuk sebuah file",
    "Deselect all files" : "Batalkan pilihan semua file",
    "Select or deselect a file" : "Pilih atau batal pilih sebuah file",
    "Select a range of files" : "Pilih rentang file",
    "Navigate to the parent folder" : "Navigasi ke folder induk",
    "Navigate to the file above" : "Navigasi ke file di atas",
    "Navigate to the file below" : "Navigasi ke file di bawah",
    "Navigate to the file on the left (in grid mode)" : "Navigasi ke file di kiri (dalam mode grid)",
    "Navigate to the file on the right (in grid mode)" : "Navigasi ke file di kanan (dalam mode grid)",
    "Toggle the grid view" : "Alihkan tampilan grid",
    "Open the sidebar for a file" : "Buka bilah samping untuk sebuah file",
    "You" : "Anda",
    "Shared multiple times with different people" : "Dibagikan beberapa kali dengan orang yang berbeda",
    "Unable to change the favorite state of the file" : "Tidak dapat mengubah status favorit file",
    "Error while loading the file data" : "Galat pemuatan data berkas",
    "Tags" : "Tag",
    "Save as …" : "Simpan sebagai …",
    "Converting files …" : "Mengonversi file …",
    "Converting file …" : "Mengonversi file …",
    "Deletion cancelled" : "Penghapusan dibatalkan",
    "Edit locally" : "Sunting secara lokal",
    "Moving \"{source}\" to \"{destination}\" …" : "Memindahkan \"{source}\" ke \"{destination}\" …",
    "Copying \"{source}\" to \"{destination}\" …" : "Menyalin \"{source}\" ke \"{destination}\" …",
    "(copy)" : "(salinan)",
    "(copy %n)" : "(salinan %n)",
    "Move cancelled" : "Pemindahan dibatalkan",
    "Cancelled move or copy of \"{filename}\"." : "Pemindahan atau penyalinan \"{filename}\" dibatalkan.",
    "Cancelled move or copy operation" : "Operasi pemindahan atau penyalinan dibatalkan",
    "Open details" : "Buka detail",
    "Photos and images" : "Foto dan gambar",
    "New folder creation cancelled" : "Pembuatan folder baru dibatalkan",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktori ini tidak tersedia, silakan periksa log atau hubungi kontak",
    "All folders" : "Semua folder",
    "Open file sidebar" : "Buka bilah samping file",
    "Search everywhere …" : "Cari di mana saja …",
    "Search here …" : "Cari di sini …",
    "Preparing …" : "Menyiapkan …"
},
"nplurals=1; plural=0;");
